pub struct StateCommitment {
pub timestamp: u64,
pub overlay_root: Option<H256>,
pub state_root: H256,
}Expand description
The state commitment represents a commitment to the state machine’s state (trie) at a given height. Optionally holds a commitment to the ISMP request/response trie if supported by the state machine.
Fields
timestamp: u64Timestamp in seconds
overlay_root: Option<H256>Root hash of the request/response overlay trie if the state machine supports it.
state_root: H256Root hash of the global state trie.
Implementations