TimeoutMessage

Enum TimeoutMessage 

pub enum TimeoutMessage {
    Post {
        requests: Vec<Request>,
        timeout_proof: Proof,
    },
    PostResponse {
        responses: Vec<PostResponse>,
        timeout_proof: Proof,
    },
    Get {
        requests: Vec<Request>,
    },
}
A timeout message holds a batch of messages to be timed-out

Variants



Post

A non memership proof for POST requests

Fields

requests: Vec<Request>

Request timeouts

timeout_proof: Proof

Non membership batch proof for these requests



PostResponse

A non memership proof for POST requests

Fields

responses: Vec<PostResponse>

Request timeouts

timeout_proof: Proof

Non membership batch proof for these requests



Get

There are no proofs for Get timeouts, we only need to ensure that the timeout timestamp has elapsed on the host

Fields

requests: Vec<Request>

Requests that have timed out

Implementations

Source

impl TimeoutMessage

pub fn requests(&self) -> Vec<Request>

Get all the inner requests

pub fn timeout_proof(&self) -> Result<&Proof, Error>

Returns the associated proof