pub enum Error {
Show 38 variants
UnbondingPeriodElapsed {
consensus_state_id: ConsensusStateId,
},
ChallengePeriodNotElapsed {
state_machine_id: StateMachineId,
update_time: Duration,
current_time: Duration,
},
ConsensusStateNotFound {
consensus_state_id: ConsensusStateId,
},
StateCommitmentNotFound {
height: StateMachineHeight,
},
FrozenConsensusClient {
consensus_state_id: ConsensusStateId,
},
RequestCommitmentNotFound {
meta: Meta,
},
RequestVerificationFailed {
meta: Meta,
},
RequestTimeoutNotElapsed {
meta: Meta,
timeout_timestamp: Duration,
state_machine_time: Duration,
},
RequestTimeoutVerificationFailed {
meta: Meta,
},
ResponseVerificationFailed {
meta: Meta,
},
ConsensusProofVerificationFailed {
id: ConsensusClientId,
},
ExpiredConsensusClient {
id: ConsensusClientId,
},
CannotHandleMessage,
MembershipProofVerificationFailed(String),
NonMembershipProofVerificationFailed(String),
Custom(String),
CannotCreateAlreadyExistingConsensusClient {
id: ConsensusClientId,
},
InsufficientProofHeight,
ModuleNotFound(Vec<u8>),
ConsensusStateIdNotRecognized {
consensus_state_id: ConsensusStateId,
},
ChallengePeriodNotConfigured {
state_machine: StateMachineId,
},
DuplicateConsensusStateId {
consensus_state_id: ConsensusStateId,
},
UnnbondingPeriodNotConfigured {
consensus_state_id: ConsensusStateId,
},
ModuleDispatchError {
msg: String,
meta: Meta,
},
UnknownRequest {
meta: Meta,
},
UnknownResponse {
meta: Meta,
},
UnsolicitedResponse {
meta: Meta,
},
RequestTimeout {
meta: Meta,
},
ResponseTimeout {
response: Meta,
},
DuplicateRequest {
meta: Meta,
},
DuplicateResponse {
meta: Meta,
},
RequestProofMetadataNotValid {
meta: Meta,
},
RequestProxyProhibited {
meta: Meta,
},
ResponseProxyProhibited {
meta: Meta,
},
InvalidRequestDestination {
meta: Meta,
},
InvalidResponseDestination {
meta: Meta,
},
InvalidResponseType {
meta: Meta,
},
SignatureDecodingFailed,
}Expand description
Errors that may be encountered by the ISMP module
Variants
UnbondingPeriodElapsed
The unbonding period for the given consensus client has elapsed and can no longer process consensus updates.
Fields
consensus_state_id: ConsensusStateIdThe consensus client identifier
ChallengePeriodNotElapsed
The challange period for the given consensus client has not yet elapsed and cannot process new consensus updates in the mean time.
Fields
state_machine_id: StateMachineIdThe consensus client identifier
ConsensusStateNotFound
A consensus state was not found for the given consensus client.
Fields
consensus_state_id: ConsensusStateIdThe consensus client identifier
StateCommitmentNotFound
A state commitment was not found for the given consensus client.
Fields
height: StateMachineHeightThe given state machine height
FrozenConsensusClient
The given consensus client has been frozen
Fields
consensus_state_id: ConsensusStateIdThe consensus client identifier
RequestCommitmentNotFound
The given request was not found
RequestVerificationFailed
The given request has failed state proof verification
RequestTimeoutNotElapsed
The given request has not yet timed-out
Fields
RequestTimeoutVerificationFailed
The given request has failed non-membership state proof verification
ResponseVerificationFailed
The given response has failed membership state proof verification
ConsensusProofVerificationFailed
Failed to verify the consensus proof for the given consensus client
Fields
id: ConsensusClientIdThe consensus client identifier
ExpiredConsensusClient
The given consensus client has expired
Fields
id: ConsensusClientIdThe consensus client identifier
CannotHandleMessage
Cannot handle the given message
MembershipProofVerificationFailed(String)
Membership proof verification failed: {0}
NonMembershipProofVerificationFailed(String)
Non-membership proof verification failed: {0}
Custom(String)
Custom error: {0}
CannotCreateAlreadyExistingConsensusClient
A consensus client with the given identifier already exists
Fields
id: ConsensusClientIdThe consensus client identifier
InsufficientProofHeight
Supplied proof height is invalid
ModuleNotFound(Vec<u8>)
An Ismp Module was not found for the given raw id
ConsensusStateIdNotRecognized
Unknown consensus state id
Fields
consensus_state_id: ConsensusStateIdConsensus state Id
ChallengePeriodNotConfigured
Challenge period has not been configured for this consensus state
Fields
state_machine: StateMachineIdState Machine Id
DuplicateConsensusStateId
Consensus state id already exists
Fields
consensus_state_id: ConsensusStateIdConsensus state Id
UnnbondingPeriodNotConfigured
Unbonding period has not been configured for this consensus state
Fields
consensus_state_id: ConsensusStateIdConsensus state Id
ModuleDispatchError
Error from dispatching a request to a module
UnknownRequest
Attempted to respond to/timeout an unknown request
UnknownResponse
Attempted to time-out an unknown response
UnsolicitedResponse
Request commitment for a response does not exist
RequestTimeout
Timed out request found in batch
ResponseTimeout
Timed out response found in batch
DuplicateRequest
Duplicate request
DuplicateResponse
Duplicate response
RequestProofMetadataNotValid
Request source does not match proof metadata
RequestProxyProhibited
Proxy cannot be used when a direct connection exists
ResponseProxyProhibited
Proxy cannot be used when a direct connection exists
InvalidRequestDestination
Host is not a proxy and destination chain does is not the host
InvalidResponseDestination
The response destination does not match
InvalidResponseType
Expected get request found post
SignatureDecodingFailed
Error decoding signature