pub enum StateMachine {
Evm(u32),
Polkadot(u32),
Kusama(u32),
Substrate(ConsensusStateId),
Tendermint(ConsensusStateId),
Relay {
relay: ConsensusStateId,
para_id: u32,
},
}Expand description
Currently supported state machines.
Variants
Evm(u32)
Evm state machines
Polkadot(u32)
Polkadot parachains
Kusama(u32)
Kusama parachains
Substrate(ConsensusStateId)
Substrate-based standalone chain
Tendermint(ConsensusStateId)
Tendermint chains
Relay
Alternative relaychain parachains The state machine id also includes the consensus state id to prevent name clashes
Implementations
Sourceimpl StateMachine
impl StateMachine